==> CohortSymmetry_0.1.1.tar.gz: CohortSymmetry/inst/doc/a05_Summarise_temporal_symmetry.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  warning = FALSE,
  message = FALSE,
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 5,
  eval = Sys.getenv("$RUNNER_OS") != "macOS"
)

## ----include = FALSE----------------------------------------------------------
if (Sys.getenv("EUNOMIA_DATA_FOLDER") == "") Sys.setenv("EUNOMIA_DATA_FOLDER" = tempdir())
if (!dir.exists(Sys.getenv("EUNOMIA_DATA_FOLDER"))) dir.create(Sys.getenv("EUNOMIA_DATA_FOLDER"))
if (!CDMConnector::eunomia_is_available()) CDMConnector::downloadEunomiaData()

## ----message= FALSE, warning=FALSE, include=FALSE-----------------------------
# Load libraries
library(CDMConnector)
library(dplyr)
library(DBI)
library(CohortSymmetry)
library(duckdb)
library(DrugUtilisation)

# Connect to the database
db <- DBI::dbConnect(duckdb::duckdb(), 
                     dbdir = CDMConnector::eunomia_dir())
cdm <- cdm_from_con(
  con = db,
  cdm_schema = "main",
  write_schema = "main"
)

# Generate cohorts
cdm <- DrugUtilisation::generateIngredientCohortSet(
  cdm = cdm,
  name = "aspirin",
  ingredient = "aspirin")

cdm <- DrugUtilisation::generateIngredientCohortSet(
  cdm = cdm,
  name = "acetaminophen",
  ingredient = "acetaminophen")

## ----message= FALSE, warning=FALSE--------------------------------------------
# Generate a sequence cohort
cdm <- generateSequenceCohortSet(
  cdm = cdm,
  indexTable = "aspirin",
  markerTable = "acetaminophen",
  name = "intersect",
  combinationWindow = c(0,Inf))

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect) %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          cohortId = 1) %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          timescale = "day") %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          timescale = "year") %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          minCellCount = 0) %>% 
  dplyr::glimpse()

==> CohortSymmetry_0.1.2.tar.gz: CohortSymmetry/inst/doc/a05_Summarise_temporal_symmetry.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  warning = FALSE,
  message = FALSE,
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 5,
  eval = Sys.getenv("$RUNNER_OS") != "macOS"
)

## ----include = FALSE----------------------------------------------------------
if (Sys.getenv("EUNOMIA_DATA_FOLDER") == "") Sys.setenv("EUNOMIA_DATA_FOLDER" = tempdir())
if (!dir.exists(Sys.getenv("EUNOMIA_DATA_FOLDER"))) dir.create(Sys.getenv("EUNOMIA_DATA_FOLDER"))
if (!CDMConnector::eunomia_is_available()) CDMConnector::downloadEunomiaData()

## ----message= FALSE, warning=FALSE, include=FALSE-----------------------------
# Load libraries
library(CDMConnector)
library(dplyr)
library(DBI)
library(CohortSymmetry)
library(duckdb)
library(DrugUtilisation)

# Connect to the database
db <- DBI::dbConnect(duckdb::duckdb(), 
                     dbdir = CDMConnector::eunomia_dir())
cdm <- cdm_from_con(
  con = db,
  cdm_schema = "main",
  write_schema = "main"
)

# Generate cohorts
aspirin_code <- CodelistGenerator::getDrugIngredientCodes(
  cdm = cdm, 
  name = "aspirin"
)
cdm <- DrugUtilisation::generateDrugUtilisationCohortSet(
  cdm = cdm,
  name = "aspirin",
  conceptSet = aspirin_code
)

acetaminophen_code <- CodelistGenerator::getDrugIngredientCodes(
  cdm = cdm, 
  name = "acetaminophen"
)

cdm <- DrugUtilisation::generateDrugUtilisationCohortSet(
  cdm = cdm,
  name = "acetaminophen",
  conceptSet = acetaminophen_code
)

## ----message= FALSE, warning=FALSE--------------------------------------------
# Generate a sequence cohort
cdm <- generateSequenceCohortSet(
  cdm = cdm,
  indexTable = "aspirin",
  markerTable = "acetaminophen",
  name = "intersect",
  combinationWindow = c(0,Inf))

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect) %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          cohortId = 1) %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          timescale = "day") %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          timescale = "year") %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE--------------------------------------------
summariseTemporalSymmetry(cohort = cdm$intersect,
                          minCellCount = 0) %>% 
  dplyr::glimpse()

## ----message= FALSE, warning=FALSE, eval=FALSE--------------------------------
#  CDMConnector::cdmDisconnect(cdm = cdm)
